#!/bin/bash

tag=$(sed -n 's/^Version:\s\(.*\)$/\1/p' ./*.spec | sed -e 's/^[[:space:]]*//' -e 's/[[:space:]]*$//')
url=$(sed -n 's/^URL:\s\(.*\)$/\1/p' ./*.spec | sed -e 's/^[[:space:]]*//' -e 's/[[:space:]]*$//')
pkgdir=$(basename $url | sed -s 's/\.git$//')

echo "tag: $tag"
echo "URL: $url"
echo "pkgdir: $pkgdir"

set -e

tmp=$(mktemp -d)

trap cleanup EXIT
cleanup() {
    echo Cleaning up...
    set +e
    [ -z "$tmp" -o ! -d "$tmp" ] || rm -rf "$tmp"
}

unset CDPATH
pwd=$(pwd)

pushd "$tmp"
git clone $url
cd $pkgdir
echo Finding git tag
gittag=$(git show-ref --tags | cut -d' ' -f2 | grep '${tag}$'||git show-ref --tags | cut -d' ' -f2 | sort -nr | head -n1)
echo "Git Tag: $gittag"
if [ -z $gittag ]; then
	gittag=tags/$tag
fi
if [ -d "test" ]; then
  git archive --prefix='test/' --format=tar ${gittag}:test/ \
      | bzip2 > "$pwd"/tests-${tag}.tar.bz2
else
  echo "No test directory found for tag ${gittag}"
fi
if [ -d "support" ]; then
  git archive --prefix='support/' --format=tar ${gittag}:support/ \
      | bzip2 > "$pwd"/support-${tag}.tar.bz2
fi
if [ -d "examples" ]; then
  git archive --prefix='examples/' --format=tar ${gittag}:examples/ \
      | bzip2 > "$pwd"/examples-${tag}.tar.bz2
fi
if [ -d "tasks" ]; then
  git archive --prefix='tasks/' --format=tar ${gittag}:tasks/ \
      | bzip2 > "$pwd"/tasks-${tag}.tar.bz2
fi
popd
